@@ -46,7 +46,7 @@ def polqa_client_test(src,test,samplerate):
         print(result['result'])
     except:
         socket.close()
-    return  result
+    return  result['result']
 
 
 if __name__ == '__main__':
